@@ -1,3 +1,3 @@
 #! /usr/bin/env bash
-$EXTRACTRC `find . -name \*.rc` >> rc.cpp
+$EXTRACTRC `find . -name \*.rc` `find . -name \*.ui` >> rc.cpp
 $XGETTEXT `find . -name \*.cpp` -o $podir/kmarkdownwebview.pot
