@@ -25,7 +25,7 @@
 class MarkdownPartFactory : public KPluginFactory
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.KPluginFactory")
+    Q_PLUGIN_METADATA(IID "org.kde.KPluginFactory" FILE "kmarkdownwebviewpart.json")
     Q_INTERFACES(KPluginFactory)
 
 public:
